// LoRa Bake mit einem Arduino Nano und RA-01/RA-02 Modul
// Die Bake gibt alle 5 Sekunden einen String aus. 
//************************************************
// Author: DL2MEE Klaus Buchenrieder
//************************************************

#define Version "Vers: 1.0"
#define Freq 434100000      // Hier die Arbeitsfrequenz eintragen
#define Rufzeichen "DL0???" // Hier das eigene Rufzeichen eintragen

// Bibliothek fuer Lora von Sandeep Mistry 0.7.2
// Bibliothek fuer GFX  von Adafruit      10.1.2
// Bibliothek fuer OLED Display Adafruit   2.4.0
//  
// Verbindungen Nano und LoRa Ra-01/Ra-02 Modul: 
// LoRa MISO   -- entspricht_Arduino_Pin:D12 
// LoRa MOSI   -- entspricht_Arduino_Pin:D11
// LoRa SCLK   -- entspricht_Arduino_Pin:D13
// LoRa EN/NSS -- entspricht_Arduino_Pin:D10
// LoRa DIO0   -- entspricht_Arduino_Pin:D2
//
//TTGO 0.91s OLED connection:
//SDA -- entspricht_Arduino_Pin:A4
//SCL -- entspricht_Arduino_Pin:A5
//RST -- entspricht_Arduino_Pin: kein Pin daher in der Initialisierung die -1

#include <Wire.h>
//#include <SPI.h>
#include <LoRa.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

Adafruit_SSD1306 display(128, 64, &Wire, -1);

long frequency = Freq;  //auf dem Nano hat ein int nur 16Bit daher 'long'
int  Zaehler   = 1;
void setup() {

  Serial.begin(115200);
   
  if (!LoRa.begin(frequency)) {
    Serial.println("Fehler beim Start des LoRa Moduls");
    while (1); }
    
   LoRa.setTxPower(10); 
   LoRa.setFrequency(frequency);
   LoRa.setSpreadingFactor(10);
   LoRa.setCodingRate4(5);
   LoRa.setSignalBandwidth(125E3);
   LoRa.setPreambleLength(8);
   //LoRa.enableCrc();
   LoRa.setSyncWord(0x55); 
  
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Addresse 0x3C fuer 128x64
    Serial.println("Fehler beim Start des SSD1306 Displays");
    while(1);  }
    
  display.clearDisplay();
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setCursor(0,0);
  display.println("LoRa Bake"); 
  display.println(Version);
  display.println("Frequenz:");
  display.print(frequency);
  display.display(); 
 }

 
void loop() {

  // send packet
      while (!LoRa.beginPacket()); //LoRa.beginPacket() Gibt eine 1 
                                   //zurueck wenn gesendet werden kann.
      LoRa.print(Rufzeichen);
      LoRa.print(" *** ");
      LoRa.println(Version);
      LoRa.println(Zaehler);
      LoRa.endPacket();
      Zaehler = Zaehler + 1;
      Serial.print(Zaehler);
      Serial.println(": Packet gesendet");
      delay(5000);
 }
