// LoRa Transceiver mit einem Arduino Nano und RA-01/RA-02 Modul
// Empfänger mit Pingbutton an Pin 4 gegen Masse angeschlossen. 
// Kein Pullup Widerstand notwendig.
// Auf Tastendruck wird ein String an den Repeater gesendet.
//************************************************
// Author: DL2MEE Klaus Buchenrieder
//************************************************

#define Version "V2.00"
#define Freq 434100000
#define Rufzeichen "DLx???" // Hier das eigene Rufzeichen eintragen

// Kommentare wie in Programmierbeispiel 1

//Verbindung zum Drehgeber:
//Taster  -- entspricht_Arduino_AnschlussPin:10 Signalbezeichnung:D7 = 7
//Phase A -- entspricht_Arduino_AnschlussPin:11 Signalbezeichnung:D8 = 8
//Phase B -- entspricht_Arduino_AnschlussPin:12 Signalbezeichnung:D9 = 9

#include <Wire.h>
//#include <SPI.h>
#include <LoRa.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

// Deklaration der Drehregler Pins
const int PinSW  = 7;   // Drehgeber Taster
const int PinA   = 8;   // Drehgeber Phase A
const int PinB   = 9;   // Drehgeber Phase B
int Tastercount  = 0;   // Wie oft wurde der Taster betaetigt
int packetSize   = 0;
String RxCharacter = "";
String RxRSSI;
long frequency = Freq;  //auf dem Nano hat ein int nur 16Bit daher 'long'

// Declaration for an SSD1306 display connected to I2C (SDA, SCL pins)
Adafruit_SSD1306 display(128 /*SCREEN_WIDTH*/, 64 /*SCREEN_HEIGHT*/, &Wire, -1);

void Paket_Empfangen() {
 
    Serial.print("Received packet '"); 
    display.clearDisplay();
    display.setTextSize(1);
    display.setCursor(-12,0);
    display.print("  "); // Stellt die Printposition in den sichtbaren Bereich
   
    while (LoRa.available()) { // Stelle jedes Zeichen einzeln dar
      RxCharacter = (char)LoRa.read();
      Serial.print(RxCharacter);
      display.print(RxCharacter); } 
      
    // print RSSI of packet   
    display.println();        // Neue Zeile fuer das Empfangs RSSI
    Serial.println();
    Serial.print(" Here with RSSI ");
    Serial.println(RxRSSI);
    display.print("RX with RSSI: ");
    display.print(RxRSSI);
    display.print(" dBm");
    display.display(); } 

void Paket_Senden() {
  
    if (digitalRead (PinSW) == 0) {
     while (digitalRead (PinSW) == 0) delay(10); // Warte bis Taste wieder losgelassen wird
     Serial.println();
     Serial.println("Taste gedrückt");
     Tastercount = Tastercount + 1;

     // Display loeschen und Tastercount anzeigen
     display.clearDisplay();
     display.setTextSize(3);
     display.setTextColor(WHITE);
     display.setCursor(20,20);
     display.print(Tastercount);
     display.display();
     display.setTextSize(1);
  
     // send packet
     while (!LoRa.beginPacket()); 
      LoRa.print(Rufzeichen);
      LoRa.print(" SW: ");
      LoRa.print(Version);
      LoRa.print(" Test BK "); 
      LoRa.print(Tastercount);
      LoRa.print(" *** BK");
      LoRa.endPacket(); } }
 
void setup() {
  Serial.begin(115200);
  
  pinMode(PinSW,INPUT);       
  digitalWrite(PinSW, HIGH);  // Aktiviere den internen Pull-Up Widerstand
  pinMode(PinA ,INPUT);       // Im Schaltbild ist ein 10kOhm Pull-Up Widerstand eingebaut
  pinMode(PinB ,INPUT);       // Im Schaltbild ist ein 10kOhm Pull-Up Widerstand eingebaut
  
 while (!Serial);
  Serial.println();
  Serial.print("LoRa Receiver "); Serial.println(Version);
  
  if (!LoRa.begin(frequency)) {
    Serial.println("Starting LoRa failed!");
    while (1); }
    
   LoRa.setTxPower(5); // Wertebereich 2 bis 20dBm
   LoRa.setFrequency(frequency);
   LoRa.setSpreadingFactor(10);
   LoRa.setCodingRate4(5);
   LoRa.setSignalBandwidth(125E3);
   LoRa.setPreambleLength(8);
   //LoRa.enableCrc();
   LoRa.setSyncWord(0x55);     // Fuer Relaisbetrieb 0x73
  
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Address 0x3C for 128x64
    Serial.println(F("SSD1306 allocation failed"));
    for(;;);  }
    
  display.clearDisplay();
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setCursor(0,0);
  display.print("LoRa "); display.println(Version);
  display.println("Kein Paket");
  display.println("empfangen.");
  display.print("f= ");
  display.println(frequency);
  display.display(); } //setup
 
void loop() {
  packetSize = LoRa.parsePacket(); // Groesser 0 wenn ein Paket empfangen wurde
  RxRSSI = LoRa.packetRssi();      // RSSI des empfangenen Pakets
  if (packetSize) Paket_Empfangen();
  delay(20); // Debouncing und Vollendung des vorherigen Pakets
  if (digitalRead (PinSW) == 0) Paket_Senden();    
}
