// LoRa Empfaenger mit einem Arduino Nano und RA-01/RA-02 Modul
// der bei Empfang von Ein/Aus eine Leuchtdiode an Pin A5 schaltet.
//************************************************
// Author: DL2MEE Klaus Buchenrieder
//************************************************

#define Version "V3.00"
#define Freq 434100000

#include <Wire.h>
#include <LoRa.h>

int     packetSize = 0;
String  RxString   = "";
long    frequency  = Freq;  // Auf dem Nano hat ein int nur 16Bit daher 'long'
int     Extra_LED  = A5;    // Externe Led die über Lora gesteuert wird ist an Pin 24 des Nano

void Paket_Empfangen() {
    while (LoRa.available()) {
      RxString = RxString + (char)LoRa.read();}
    RxString.toUpperCase();                       // Ganzen RxString in Grossbuchstaben wandeln
    Serial.print("Empfangen wurde: " + RxString);  
} // Ende Paket_Empfangen()

void setup() {  
  Serial.begin(115200);
  pinMode(Extra_LED, OUTPUT);    // Externe Led die ueber LoRa gesteuert wird
  digitalWrite(Extra_LED, LOW);  // LED wird eingeschaltet - Pin auf GND.
  while (!Serial);
  
   Serial.println();
   Serial.print("LoRa Fernsteuerung einer Leuchtdiode an Pin A5 "); 
   Serial.println(Version);
   
  if (!LoRa.begin(frequency)) {
    Serial.println("Starting LoRa failed!");
    while (1); }
    
   LoRa.setTxPower(5);
   LoRa.setFrequency(frequency);
   LoRa.setSpreadingFactor(10);
   LoRa.setCodingRate4(5);
   LoRa.setSignalBandwidth(125E3);
   LoRa.setPreambleLength(8);
   //LoRa.enableCrc();
   LoRa.setSyncWord(0x55);
 }
 
void loop() {
  RxString = "";
  packetSize = LoRa.parsePacket();      // Groesser 0 wenn ein Paket empfangen wurde
  if (packetSize) Paket_Empfangen();    // Einlesen des Paketinhalts in RxString
  if (RxString.indexOf("AUS") != -1)    // Enthaelt der RxString das Wort "AUS"
    digitalWrite(Extra_LED, HIGH);      // dann wird die LED ausgeschaltet.
  if (RxString.indexOf("EIN") != -1)    // Enthaelt der RxString das Wort "EIN"
    digitalWrite(Extra_LED, LOW);       // dann wird die LED eingeschaltet.
  delay(20); // Abwarten zur Vollendung des vorherigen Pakets. Nicht wirklich notwendig.
}
